# KoLMoV

[![Build Status](https://travis-ci.org/micaelverissimo/kolmov.svg?branch=master)](https://travis-ci.org/micaelverissimo/kolmov)

KoLMoV (**K**it **o**f **L**earning **M**odels **V**alidation) A Framework to perfomance the cross validation for Ringer tunings
